@@ -49,7 +49,7 @@ bool SecurityGuard::checkModule([[maybe_unused]] const std::wstring& filePath, [
 {
 #ifndef _DEBUG
 	if (_securityMode == sm_certif)
-		return verifySignedLibrary(filePath);
+		return verifySignedBinary(filePath);
 	else if (_securityMode == sm_sha256)
 		return checkSha256(filePath, module2check);
 	else
@@ -72,7 +72,11 @@ bool SecurityGuard::checkSha256(const std::wstring& filePath, NppModule module2c
 		return true;
 	*/
 
-	std::string content = getFileContent(filePath.c_str());
+	bool bLoadingFailed = false;
+	std::string content = getFileContent(filePath.c_str(), &bLoadingFailed);
+	if (bLoadingFailed)
+		return false;
+
 	uint8_t sha2hash[32];
 	calc_sha_256(sha2hash, reinterpret_cast<const uint8_t*>(content.c_str()), content.length());
 
@@ -105,7 +109,7 @@ bool SecurityGuard::checkSha256(const std::wstring& filePath, NppModule module2c
 // Debug use
 bool doLogCertifError = false;
 
-bool SecurityGuard::verifySignedLibrary(const std::wstring& filepath)
+bool SecurityGuard::verifySignedBinary(const std::wstring& filepath)
 {
 	wstring display_name;
 	wstring key_id_hex;
