@@ -19,15 +19,13 @@
 #include "tinyxmlA.h"
 #include "tinyxml.h"
 #include "Scintilla.h"
-#include "ScintillaRef.h"
 #include "ToolBar.h"
 #include "UserDefineLangReference.h"
 #include "colors.h"
 #include "shortcut.h"
 #include "ContextMenu.h"
-#include "dpiManager.h"
 #include "NppDarkMode.h"
-#include <assert.h>
+#include <cassert>
 #include <map>
 #include <array>
 #include <shlwapi.h>
@@ -35,6 +33,8 @@
 #include "Lexilla.h"
 #include "DockingCont.h"
 
+#include "NppConstants.h"
+
 #ifdef _WIN64
 
 #ifdef _M_ARM64
@@ -1925,8 +1925,6 @@ public:
 		return _titleBarAdditional;
 	}
 
-	DPIManager _dpiManager;
-
 	std::wstring static getSpecialFolderLocation(int folderKind);
 
 	void setUdlXmlDirtyFromIndex(size_t i);
@@ -2143,6 +2141,11 @@ private:
 	bool getUserStylersFromXmlTree();
 	std::pair<unsigned char, unsigned char> addUserDefineLangsFromXmlTree(TiXmlDocument *tixmldoc);
 
+	enum ConfXml { lang, styles };
+	void updateFromModelXml(TiXmlNode* rootUser, ConfXml whichConf);
+	void updateLangXml(TiXmlElement* mainElemUser, TiXmlElement* mainElemModel);
+	void updateStylesXml(TiXmlElement* rootUser, TiXmlElement* rootModel, TiXmlElement* mainElemUser, TiXmlElement* mainElemModel);
+
 	bool getShortcutsFromXmlTree();
 
 	bool getMacrosFromXmlTree();
