@@ -48,7 +48,7 @@
 #define IDF_PURGE_CHECK	4
 #define	IDC_FINDALL_STATIC				1619
 #define	IDFINDWHAT_STATIC				1620
-//#define	IDC_DIR_STATIC					1621
+#define	IDC_FIF_FILTER_TIP_STATIC		1621
 
 #define	IDC_PERCENTAGE_SLIDER			1622
 #define	IDC_TRANSPARENT_GRPBOX 			1623
