@@ -21,4 +21,7 @@
 #define	IDC_COMBO_RUN_PATH		(IDD_RUN_DLG + 2)
 #define	IDC_MAINTEXT_STATIC     (IDD_RUN_DLG + 3)
 #define	IDC_BUTTON_SAVE         (IDD_RUN_DLG + 4)
-
+#define	IDC_BUTTON_VARIABLES    (IDD_RUN_DLG + 5)
+#define	IDR_RUN_DLG_MENU_VARIABLES 1950
+#define IDM_RUN_DLG_VARMENU_START (IDD_RUN_DLG + 60)
+#define IDM_RUN_DLG_VARMENU_END (IDM_RUN_DLG_VARMENU_START + 10)
