@@ -728,13 +728,9 @@ void WindowsDlg::updateButtonState()
 int WindowsDlg::doDialog()
 {
 	const auto dpiContext = DPIManagerV2::setThreadDpiAwarenessContext(DPI_AWARENESS_CONTEXT_UNAWARE_GDISCALED);
+	const auto result = static_cast<int>(StaticDialog::myCreateDialogBoxIndirectParam(IDD_WINDOWS, false));
+	DPIManagerV2::setThreadDpiAwarenessContext(dpiContext);
 
-	int result = static_cast<int>(DialogBoxParam(_hInst, MAKEINTRESOURCE(IDD_WINDOWS), _hParent, dlgProc, reinterpret_cast<LPARAM>(this)));
-
-	if (dpiContext != NULL)
-	{
-		DPIManagerV2::setThreadDpiAwarenessContext(dpiContext);
-	}
 	return result;
 }
 
