@@ -33,7 +33,7 @@ public:
 	void Clear() noexcept;
 	bool Set(const char *s, bool lowerCase=false);
 	bool InList(const char *s) const noexcept;
-	bool InList(const std::string &s) const noexcept;
+	bool InList(std::string_view sv) const noexcept;
 	bool InListAbbreviated(const char *s, const char marker) const noexcept;
 	bool InListAbridged(const char *s, const char marker) const noexcept;
 	const char *WordAt(int n) const noexcept;
